pub trait ExtractFuture {
type Item;
// Required methods
fn poll(&mut self) -> Poll<(), Error>;
fn extract(self) -> Self::Item;
}Expand description
Future representing the completion of extracting a value from a request
Implementations are expected to advance to a state where extract will
succeed. This is done by performing any asynchronous processing when poll
is called and usually stashing the extracted value internally until
extract is called.
extract must not be called until poll returns Ok(Ready(())).
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".