Module log

Module log 

Middleware that creates a log entry for each HTTP request.

Structs

LogMiddleware
Decorate a service by logging all received requests.
LogService
Decorates a service by logging all received requests
ResponseFuture
Log the received request once the response has been processed.